ch_long: Capture Histories - Long Format

ch_longR Documentation

Capture Histories - Long Format

Description

Capture histories, in long format, for 5 receivers and tags in tag_df from Lemhi River juvenile Chinook salmon winter telemetry project

Usage

ch_long

Format

A data frame with 54 rows and 6 variables:

tag_id

tag ID including frequency and code

loc

observation location, site or receiver

first_obs

the date and time of first observation at loc

last_obs

the date and time of last observation at loc

n

the number of records that occurred between first_obs and last_obs

week

the week number the first observation is from

Biomark NAS - data/telemetry/lemhi/fixed_site_downloads/2018_2019/


mackerman44/telemetyr documentation built on Feb. 15, 2025, 1:08 a.m.