| get_file_nms | R Documentation |
Create a data frame of all downloaded files for a telemetry season
get_file_nms(path = ".", receiver_codes = NULL)
path |
a path to the directory containing all of the files downloaded from radio telemetry receivers for a study season and using the Tracker software |
receiver_codes |
character vector of receiver codes to download files for.
The default is |
a data frame of all files contained in path
Kevin See and Mike Ackerman
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.