read_volt_temp_data: Read in Receiver Volt and Temperature Info from Tracker...

View source: R/read_volt_temp_data.R

read_volt_temp_dataR Documentation

Read in Receiver Volt and Temperature Info from Tracker Software

Description

Reads in volt and temperature data from the Tracker software

Usage

read_volt_temp_data(path = ".", receiver_codes = NULL)

Arguments

path

a path to the directory containing all of the files downloaded from radio telemetry receivers for a study season and using the Tracker software

receiver_codes

character vector of receiver codes to download files for. The default is NULL, which will keep all receiver codes found in the path folder

Value

a data frame containing receiver volt and temperature information

Author(s)

Mike Ackerman and Kevin See


mackerman44/telemetyr documentation built on Feb. 15, 2025, 1:08 a.m.