| ch_long | R Documentation |
Capture histories, in long format, for 5 receivers and tags
in tag_df from Lemhi River juvenile Chinook salmon winter
telemetry project
ch_long
A data frame with 54 rows and 6 variables:
tag ID including frequency and code
observation location, site or receiver
the date and time of first observation at loc
the date and time of last observation at loc
the number of records that occurred between first_obs and last_obs
the week number the first observation is from
Biomark NAS - data/telemetry/lemhi/fixed_site_downloads/2018_2019/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.