View source: R/read_volt_temp_data.R
| read_volt_temp_data | R Documentation |
Reads in volt and temperature data from the Tracker software
read_volt_temp_data(path = ".", receiver_codes = NULL)
path |
a path to the directory containing all of the files downloaded from radio telemetry receivers for a study season and using the Tracker software |
receiver_codes |
character vector of receiver codes to download files for.
The default is |
a data frame containing receiver volt and temperature information
Mike Ackerman and Kevin See
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.